#
# spec file for package mate-icon-theme
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-icon-theme
Version:        1.28.0
Release:        1.2
Summary:        MATE icon theme
License:        CC-BY-3.0 AND LGPL-3.0-only
Group:          System/X11/Icons
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  icon-naming-utils >= 0.8.7
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
Provides:       mate-icon-theme-devel = %{version}
BuildArch:      noarch

%description
This package contains the default icon theme used by the MATE desktop.
The icons are used in the panel menu, and in nautilus and other
applications, to represent the different applications, files,
directories, and devices.

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure
%make_build

%install
%make_install
%fdupes %{buildroot}%{_datadir}/icons

%files
%license COPYING
%doc AUTHORS NEWS
%{_datadir}/icons/mate/
%ghost %{_datadir}/icons/mate/icon-theme.cache
%{_datadir}/icons/menta/
%ghost %{_datadir}/icons/menta/icon-theme.cache

%changelog
* Wed Mar 27 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Update translations
* Sat Aug 14 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * Remove the execution bit from some png files
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.1):
  * Add mate/256x256/actions/mail-send.png.
  * Fix mate/22x22/devices/printer.png.
  * Upscale 22x22px icons to 24x24px adding 1px to the edges.
  * Gen png mimetypes icons from paper-sheets.svg - MATE theme.
  * preferences-system-time.png files are not generated from
    sources.
  * Use radial gradient (Blur 13.9%%, Opacity 73.4%%) for MATE logo
    shadow.
  * Add status icons for mobile network connections.
  * Rework volume-status icons.
  * Add vpn network status icons.
  * Update network status icons.
  * Add network svg icons.
  * Add dropbox-status icons.
  * Re-generate network-wired icons from new SVGs.
  * Add 2 svg sources for nm-applet.
  * Migrate from intltool to gettext.
  * Update translations.
- Drop support for old openSUSE versions.
* Wed Jul 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.1 (changes since 1.22.1):
  * tx: sync with transifex
  * add missing preferences-system-time icon
  * Change url project's website
  * use folder icon as example
  * rename mate logo
  * Translations update
  * Display the volume status with a better contrast in panels
  * Upgrade svg source files to Inkscape 0.92.4
  * Gen png icons from source - Mate theme
  * Gen png icons from source. Mate: apps, categories & devices
  * Update terminal icons for mate theme
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Display the volume status with a better contrast in panels.
  * Upgrade svg source files to Inkscape 0.92.4.
  * Gen png icons from source - mate theme.
  * Gen png icons from source. mate: apps, categories & devices.
  * Update terminal icons for mate theme.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * No changelog available.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.3 (changes since 1.20.1):
  * Add video single and joined display symbolic svg icons.
  * Symlink input-touchpad.svg icon.
  * Add a symlink for bluetooth icon.
  * Add icons for touchpad.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * mate: Add audio-volume-off.
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0 (changes since 1.18.1):
  * Fix some broken iso flag images.
  * Update translations.
* Mon Apr  3 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Add SVG ISO flags.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Add missing mate.svg.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Add system-config-keyboard icons.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Do not build a pkgconfig file.
* Thu Aug 27 2015 sor.alexei@meowr.ru
- Generate icon cache.
* Tue Jun  9 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Add more regular icons.
  * Update symbolic icons.
- Spec cleanup.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.1
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  * Add symbolic icons for GTK3 compatibility
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + no changes since version 1.8.0
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + Menta: Add avatar default icons for new lightdm
  + add bluetooth icons for bluedevil
- Remove useless xz requirement
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.1
  + Mate: fix scalable directories in index.theme
  + fix typo in makefile
    Closes #10 (https://github.com/mate-desktop/mate-icon-theme/issues/10)
  + mate: add bluetooth icons for using bluedevil
  + Many changes in Menta
  - fix Inherits in index.theme
  - remove symbolic icons
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.3
  + Menta: remove symbolic icons
  + Menta: fix Inherits in index.theme
  + mate: add bluetooth icons for using bluedevil
  + Fix typo in makefile
    Closes #10 (https://github.com/mate-desktop/mate-icon-theme/issues/10)
  + Mate: fix scalable directories in index.theme
* Tue Sep  3 2013 p.drouand@gmail.com
- Update to version 1.6.2
  + add avatar-default icons for new lightdm in Menta
  + add sympolic icons to mate icon theme
  + fix scalable directories in index.theme
  + add make file
* Tue Jun 25 2013 johann.luce@wanadoo.fr
- Update to version 1.6.1
  + On make install, the Makefile will now copy .icon files into the pack
    age dir too, allowing for text-x-preview.icon (a requirement for text
    file preview) to be included in the package.
  + Merge pull request #7 from iFrag/master Text preview .icon file now
    included in package
  + add + and - icons for Menta icon theme
  + add scalable symbolic icons to Menta theme
  + Merge pull request #8 from NiceandGently/master add scalable symbolic
    icons to Menta theme
  + Create xz tarball
  + Add missing uninstall hooks
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + add some mimetypes icons
  + fix index.theme in Menta
* Sat Mar 23 2013 p.drouand@gmail.com
- Update to version 1.5.1
  + Add Menta icon set
  + Enable text preview in text-x-preview icon
    This update fixes bug with plain-text thumbnails in Caja. Without
    this fix text from plain-text files do not displayed on thumbnails
* Wed Oct 10 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + bump version, no changes
* Sat Sep  8 2012 nmo.marques@gmail.com
- copypac to X11:MATE
  + minor cosmetic fixes
  + fix license entries
* Sat Aug  4 2012 hillwood@linuxfans.org
- Update to version 1.4.0
* Fri Dec 30 2011 nmarques@opensuse.org
- Initial package from version 1.2.0
